@@ -78,7 +78,8 @@ char *WriteBadFlagFile()
  if (BADFLAG_TRACE) Arena_TracePrint(Iam, " Filespec %s\n", tfile);
 #endif
 
- if ((fd = creat(tfile, S_IRUSR | S_IWUSR)) == -1)
+   unlink(tfile);
+   if ((fd = open(tfile, O_RDWR | O_CREAT | O_EXCL, 0600)) < 0)
    {
 #ifdef ARENA_DEBUG
     if (BADFLAG_TRACE) Arena_TracePrint(Iam, " creat failed %s\n", tfile);
