@@ -3,8 +3,13 @@
  */
 
 
-#include <stdarg.h>
-#include <stdio.h>  /* STUPID ALPHA/OSF - GCC !!!!! */
+
+#include <stdio.h>  /* STUPID DIGITAL UNIX!!!!! */
+#ifdef __STDC__
+#  include <stdarg.h>
+# else
+#  include <varargs.h>
+#endif
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/Xos.h>
