@@ -1075,6 +1075,7 @@ void PrintDoc(void)
 void DisplayPSdocument(char *buffer, long length, char *path)
 {
  FILE *fp;
+ int fd;
  char *tmpfile, *p, buf[256], cmd[256];
 
  p = ARENA_rIndex(path, '/');
@@ -1088,8 +1089,9 @@ void DisplayPSdocument(char *buffer, long length, char *path)
    tmpfile = tempnam(".", "w3");
 
  p = buffer;
-
- if ((fp = fopen(tmpfile, "w")) == 0)
+ unlink(tmpfile);
+ fd = open(tmpfile, O_RDWR | O_CREAT | O_EXCL, 0640);
+ if (fd < 0 || (fp = fdopen(fd, "w")) == 0)
    Warn("Can't open temporary postscript: file, %s\n", tmpfile);
   else
    {
@@ -1119,6 +1121,7 @@ void DisplayExtDocument(char *buffer, long length, int type, char *path)
 {
  FILE *fp;
  char *tmpfile, *p, *app, cmd[256], buf[256];
+ int fd;
 #ifdef ARENA_DEBUG
  char Iam[] = "DisplayExtDocument";
 #endif
@@ -1136,9 +1139,11 @@ void DisplayExtDocument(char *buffer, long length, int type, char *path)
 
  p = buffer;
 
- if ((fp = fopen(tmpfile, "w")) == 0)
+ unlink(tmpfile);
+ fd = open(tmpfile, O_RDWR | O_CREAT | O_EXCL, 0640);
+ if (fd < 0 || (fp = fdopen(fd, "w")) == 0)
    Warn("Can't open temporary file: %s\n", tmpfile);
-  else
+ else
    {
     while (length-- > 0) putc(*p++, fp);
 
@@ -1194,6 +1199,7 @@ void SaveDoc(char* theFileName)
  static char* SaveAsString = NULL;
  long i;
  FILE* fp;
+ int fd;
  char* p;
  char* fileName;
 
@@ -1211,7 +1217,9 @@ void SaveDoc(char* theFileName)
 
  p = buffer + hdrlen;
 
- if ((fp = fopen(fileName, "w")))
+ unlink(fileName);
+ fd = open(fileName, O_RDWR | O_CREAT | O_EXCL, 0640);
+ if (fd >= 0 && (fp = fdopen(fd, "w")) != 0)
    {
 #if 0	/* QingLong.25-09-97 */
     if (!CurrentDoc->show_raw)
